@@ -3,13 +3,14 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide access to hundreds of possible chord progressions
 
-our $VERSION = '0.0109';
+our $VERSION = '0.0200';
 
 use strict;
 use warnings;
 
 use Text::CSV_XS ();
 use File::ShareDir qw(dist_dir);
+use Music::Scales qw(get_scale_notes);
 
 
 
@@ -63,6 +64,19 @@ sub as_hash {
     return %data;
 }
 
+
+sub transpose {
+    my ($note, $scale, $progression) = @_;
+
+    my %note_map;
+    @note_map{ get_scale_notes('C', $scale) } = get_scale_notes($note, $scale);
+
+    # transpose the progression chords from C
+    (my $named = $progression->[0]) =~ s/([A-G][#b]?)/$note_map{$1}/g;
+
+    return $named;
+}
+
 1;
 
 __END__
@@ -77,7 +91,7 @@ Data::Dataset::ChordProgressions - Provide access to hundreds of possible chord
 
 =head1 VERSION
 
-version 0.0109
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -89,6 +103,10 @@ version 0.0109
 
   my %data = Data::Dataset::ChordProgressions::as_hash();
 
+  my $named = Data::Dataset::ChordProgressions::transpose(
+    'A', 'major', ['C-F-Am-F', 'I-IV-vi-IV']
+  );
+
 =head1 DESCRIPTION
 
 C<Data::Dataset::ChordProgressions> provides access to hundreds of
@@ -108,7 +126,7 @@ C<"Eb7-Eb7-Eb7-Eb7","III-III-III-III">.  Strange...
 
 I stumbled across this list, saved it on my hard-drive for a long
 time, and then forgot where it came from!  Also the documentation in
-this list said nothing about who made it or how.
+the original list said nothing about who made it or how.
 
 =head1 FUNCTIONS
 
@@ -130,13 +148,26 @@ Return the data as an array.
 
 Return the data as a hash.
 
+=head2 transpose
+
+  $named = transpose($note, $scale, $progression);
+
+Transpose a B<progression> in the key of C<C> to the given B<note> and
+B<scale>.
+
+The progression must be the array-reference value of
+C<$data{$style}{$scale}{$section}>, as given by the C<as_hash()>
+function, and having the form of, for example:
+
+  [ 'C-F-Am-F', 'I-IV-vi-IV' ]
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by Gene Boggs.
+This software is copyright (c) 2023 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
